@@ -8,7 +8,7 @@
  *
  * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -53,17 +53,23 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 
+// libkipi includes
+
+#include <libkipi/imageinfo.h>
+#include <libkipi/interface.h>
+
 // Local includes
 
-#include "common.h"
+#include "commoncontainer.h"
 #include "slideplaybackwidget.h"
 #include "slideshowloader.h"
+#include "playbackwidget.h"
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
-SlideShow::SlideShow( const FileList& fileList, const QStringList& commentsList, SharedData* sharedData )
-         : QWidget( 0, Qt::WindowStaysOnTopHint | Qt::Popup | Qt::X11BypassWindowManagerHint )
+SlideShow::SlideShow(const FileList& fileList, const QStringList& commentsList, SharedContainer* sharedData)
+         : QWidget(0, Qt::WindowStaysOnTopHint | Qt::Popup | Qt::X11BypassWindowManagerHint)
 {
     setAttribute(Qt::WA_DeleteOnClose);
 
@@ -414,8 +420,8 @@ void SlideShow::printComments()
     if (m_currImage.isNull())
         return;
 
-    KIPI::ImageInfo info = m_sharedData->interface->info(m_imageLoader->currPath());
-    QString comments = info.description();
+    KIPI::ImageInfo info = m_sharedData->iface()->info(m_imageLoader->currPath());
+    QString comments     = info.description();
 
     int yPos = 30; // Text Y coordinate
 
@@ -1324,7 +1330,7 @@ void SlideShow::paintEvent( QPaintEvent * )
         p.drawText( 100, 100, i18n( "Slideshow Completed" ) );
         p.drawText( 100, 100+10+fn.pointSize(), i18n( "Click to Exit..." ) );
 
-        QSvgRenderer svgRenderer( KStandardDirs::locate( "data", "kipiplugin_advancedslideshow/KIPIicon.svg" ) );
+        QSvgRenderer svgRenderer( KStandardDirs::locate("data", "kipi/data/kipi-icon.svg") );
         QPixmap kipiLogoPixmap = QPixmap( width()/6, width()/6 );
         kipiLogoPixmap.fill( Qt::black );
         QPaintDevice* pdp = &kipiLogoPixmap;
