@@ -24,7 +24,7 @@
 
 // KDE includes
 
-#include <KDebug>
+#include <kdebug.h>
 #include <KConfig>
 #include <KLocale>
 
