@@ -23,13 +23,13 @@
 #include "exifdatetime.h"
 #include "exifdatetime.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QCheckBox>
 #include <QPushButton>
 #include <QGridLayout>
 
-// KDE includes.
+// KDE includes
 
 #include <kaboutdata.h>
 #include <kcomponentdata.h>
@@ -41,8 +41,9 @@
 #include <knuminput.h>
 #include <kseparator.h>
 
-// LibKExiv2 includes.
+// LibKExiv2 includes
 
+#include <libkexiv2/version.h>
 #include <libkexiv2/kexiv2.h>
 
 namespace KIPIMetadataEditPlugin
@@ -507,7 +508,12 @@ void EXIFDateTime::applyMetadata(QByteArray& exifData, QByteArray& iptcData, QBy
     else
         exiv2Iface.removeExifTag("Exif.Photo.SubSecTimeDigitized");
 
+#if KEXIV2_VERSION >= 0x010000
+    exifData = exiv2Iface.getExifEncoded();
+#else
     exifData = exiv2Iface.getExif();
+#endif
+
     iptcData = exiv2Iface.getIptc();
     xmpData  = exiv2Iface.getXmp();
 }
