@@ -45,7 +45,7 @@ public:
     void applyMetadata(QByteArray& iptcData);
     void readMetadata(QByteArray& iptcData);
 
-signals:
+Q_SIGNALS:
 
     void signalModified();
 
