@@ -23,7 +23,7 @@
 #ifndef IPTC_STATUS_H
 #define IPTC_STATUS_H
 
-// Qt includes.
+// Qt includes
 
 #include <QWidget>
 #include <QByteArray>
@@ -45,7 +45,7 @@ public:
     void applyMetadata(QByteArray& iptcData);
     void readMetadata(QByteArray& iptcData);
 
-signals:
+Q_SIGNALS:
 
     void signalModified();
 
