@@ -30,19 +30,19 @@
 
 // Local includes
 
-#include "ui_picasawebnewalbumdialog.h"
+//#include "ui_picasawebnewalbumdialog.h"
 
 namespace KIPIPicasawebExportPlugin
 {
 
-class NewAlbumDialog : public QDialog, public Ui::NewAlbumDialog
+class NewAlbumDialog : public QDialog//, public Ui::NewAlbumDialog
 {
 
 public:
 
     NewAlbumDialog( QWidget *parent ) : QDialog( parent )
     {
-	setupUi( this );
+        //setupUi( this );
     }
 };
 
