@@ -102,12 +102,10 @@ private Q_SLOTS:
     void slotUserChangeRequest(bool anonymous);
     void slotReloadAlbumsRequest();
     void slotNewAlbumRequest();
-    void slotTransferCancel();
-    void slotLoginCancel();
     void slotHelp();
-    void slotClose();
     void slotStartTransfer();
     void slotImageListChanged();
+    void slotButtonClicked(int button);
     void slotTemplateSelectionChanged(int index);
     void slotCategorySelectionChanged(int index);
 
@@ -140,8 +138,6 @@ private:
     int                       m_currentTmplID;
     int                       m_currentCategoryID;
 
-    KProgressDialog          *m_progressDlg;
-    KProgressDialog          *m_authProgressDlg;
     KPasswordDialog          *m_loginDlg;
 
     KUrl::List                m_transferQueue;
